from ._reporter import HueReporter


def pytest_addoption(parser):
    group = parser.getgroup('terminal reporting')
    group.addoption(
        '--hue-ip',
        dest='hue_ip',
        action='store',
        type=str,
        default=None,
        help='IP address for Phillips Hue reporting'
    )
    group.addoption(
        '--hue-username',
        dest='hue_username',
        action='store',
        type=str,
        default=None,
        help='Username for Phillips Hue reporting'
    )
    group.addoption(
        '--hue-rooms',
        dest='hue_rooms',
        action='store',
        type=str,
        nargs='+',
        default=[],
        help='Rooms to control with Phillips Hue reporting'
    )


def pytest_configure(config):
    hue_ip = config.option.hue_ip
    hue_username = config.option.hue_username
    hue_rooms = config.option.hue_rooms
    if hue_ip:
        config._hue_reporter = HueReporter(hue_ip, hue_username, hue_rooms)
        config.pluginmanager.register(config._hue_reporter)


def pytest_unconfigure(config):
    hue_reporter = getattr(config, '_hue_reporter', None)
    if hue_reporter:
        del config._hue_reporter
        config.pluginmanager.unregister(hue_reporter)



import pyhue


class HueReporter(object):
    def __init__(self, hue_ip, hue_username, hue_rooms):
        self.bridge = pyhue.Bridge(hue_ip, hue_username)
        self.rooms = \
            [room for room in self.bridge.groups if room.name in hue_rooms]
        self.tests = 0.0
        self.run_tests = 0.0
        self.passed_tests = 0.0
        self.failed_tests = 0.0
        self.skipped_tests = 0.0

    def set_tests(self, tests):
        self.tests = tests

    def initialise_test_run(self):
        for room in self.rooms:
            for light_id in room.lights:
                light = self.bridge.get_light(light_id)
                light.on = True
                light.bri = 0
                light.xy = pyhue.rgb2xy(255, 255, 255)

    def add_run_test(self):
        self.run_tests += 1
        for room in self.rooms:
            for light_id in room.lights:
                light = self.bridge.get_light(light_id)
                brightness = int(255 * (self.run_tests / self.tests))
                red = int(255 * (self.failed_tests / self.tests))
                green = int(255 * (self.passed_tests / self.tests))
                blue = int(255 * (self.skipped_tests / self.tests))
                hue = pyhue.rgb2xy(red, green, blue)
                light.bri = brightness
                light.xy = hue

    def add_passing_test(self):
        self.passed_tests += 1
        self.add_run_test()

    def add_failed_test(self):
        self.failed_tests += 1
        self.add_run_test()

    def add_skipped_test(self):
        self.skipped_tests += 1
        self.add_run_test()

    def pytest_collection_modifyitems(self, config, items):
        self.set_tests(len(items))
        self.initialise_test_run()

    def pytest_runtest_logreport(self, report):
        if report.when == 'call':
            if report.passed:
                self.add_passing_test()
            if report.skipped:
                self.add_skipped_test()
            if report.failed:
                self.add_failed_test()



#!/usr/bin/env python

import os
from setuptools import setup, find_packages

from pytest_hue import __prog__, __version__, __author__, __email__, __description__, __keywords__, __license__, __url__

setup(
    name=__prog__,
    version=__version__,
    author=__author__,
    author_email=__email__,
    description=__description__,
    long_description=open(os.path.join(os.path.dirname(__file__), 'README.md')).read(),
    license=__license__,
    url=__url__,
    keywords=__keywords__,
    classifiers=[
        'Framework :: Pytest',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: POSIX',
        'Operating System :: Unix',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'License :: OSI Approved :: GNU General Public License (GPL)'
    ],
    packages=find_packages(exclude=['tests*']),
    install_requires=[
        'pytest>=3.6',
        'six>=1.0.0'
    ],
    extras_require={
        'test': [
            'pytest-xdist>=1.26.0'
        ]
    },
    entry_points={
        'pytest11': [
            'pytest_hue = pytest_hue._plugin',
        ]
    },
)


__prog__ = 'pytest-hue'
__author__ = 'Colin Wren'
__email__ = 'gimpneek@gmail.com'
__url__ = 'https://github.com/Gimpneek/pytest-hue'
__copyright__ = 'copyright 2019 pytest-hue contributors'
__license__ = 'GPLv3'
__description__ = 'Visualise PyTest status via your Phillips Hue lights'
__keywords__ = 'py.test pytest phillips hue lights report'
__version__ = '1.0.0'
